# -*- coding: utf-8 -*-
# #############################################################################
# Copyright (C) 2025 manatlan manatlan[at]gmail(dot)com
#
# MIT licence
#
# https://github.com/manatlan/reqman4
# #############################################################################

__version__ = r"0.5.0" # <-- replaced by build.py (extract from pyproject.toml)

"""
Special keys :

 * proxy: <string>          # default None
 * timeout: <milliseconds>  # default 60_000 ms
 * root: <string>           # default None
 * --<switch>: <dict/mapping>   # default {}
 * headers: <dict/mapping>   # default {}
 * BEGIN: <list>
 * END: <list>

"""
